@@ -69,6 +69,10 @@ class FrontendHighlighter(PygmentsHighlighter):
         current_block = self.currentBlock()
         string = current_block.text()
 
+        # QTextBlock::text() can still return non-breaking spaces
+        # for the continuation prompt
+        string = string.replace("\xa0", " ")
+
         # Only highlight if we can identify a prompt, but make sure not to
         # highlight the prompt.
         without_prompt = self.transform_ipy_prompt(string)
